@@ -1,17 +1,24 @@
 
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_TARNAME "am-utils"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i686"
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.4.9-13debug"
+#define HOST_OS_VERSION "2.4.20-46.7.legacy"
 #define HOST_ARCH "i386"
-#define HOST_NAME "dhcp9.fsl.cs.sunysb.edu"
+#define DISTRO_NAME "rh7.3"
+#define HOST_NAME "a-rh73.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Nov 14 22:04:36 EST 2001"
+#define CONFIG_DATE "Thu May 11 11:28:14 EDT 2006"
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
-#define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
+#define VERSION "6.2a2"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -24,21 +31,22 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "2.4.9-13"
+#ifdef __cplusplus
+void exit (int);
+#endif
+#define HOST_HEADER_VERSION "2.4.9-9"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
-#define HAVE_LIBLDAP 1
 #define HAVE_LIBRT 1
-#define HAVE_LIBGDBM 1
-#define HAVE_ALLOCA_H 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
+#define GETPGRP_VOID 1
+#define SETPGRP_VOID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
@@ -55,13 +63,15 @@
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_HASMNTOPT 1
-#define HAVE_LDAP_OPEN 1
+#define HAVE_HSTRERROR 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MEMSET 1
 #define HAVE_MKDIR 1
 #define HAVE_MKSTEMP 1
+#define HAVE_MLOCKALL 1
 #define HAVE_MOUNT 1
 #define HAVE_REGCOMP 1
 #define HAVE_REGEXEC 1
@@ -73,10 +83,13 @@
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STATVFS 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
 #define HAVE_STRSPN 1
@@ -86,6 +99,7 @@
 #define HAVE_SYSLOG 1
 #define HAVE_UNAME 1
 #define HAVE_UMOUNT 1
+#define HAVE_UMOUNT2 1
 #define HAVE_VFORK 1
 #define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
@@ -94,6 +108,7 @@
 #define HAVE_HASMNTOPT 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
+#define HAVE_STRERROR 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
@@ -141,14 +156,13 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_DB1_NDBM_H 1
-#define HAVE_LINUX_AUTO_FS_H 1
 #define HAVE_LINUX_FS_H 1
 #define HAVE_LINUX_KDEV_T_H 1
 #define HAVE_LINUX_LIST_H 1
 #define HAVE_LINUX_NFS_H 1
-#define HAVE_LINUX_NFS_MOUNT_H 1
+#define HAVE_LINUX_NFS2_H 1
 #define HAVE_LINUX_POSIX_TYPES_H 1
+#define HAVE_LINUX_SOCKET_H 1
 #define HAVE_NET_IF_H 1
 #define HAVE_NET_ROUTE_H 1
 #define HAVE_NETINET_IF_ETHER_H 1
@@ -169,6 +183,7 @@
 #define HAVE_SYS_ERRNO_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
+#define HAVE_SYS_MMAN_H 1
 #define HAVE_SYS_MOUNT_H 1
 #define HAVE_SYS_PARAM_H 1
 #define HAVE_SYS_RESOURCE_H 1
@@ -176,6 +191,7 @@
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATFS_H 1
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
@@ -188,9 +204,8 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_GRP_H 1
-#define HAVE_LBER_H 1
-#define HAVE_LDAP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_MNTENT_H 1
@@ -206,27 +221,36 @@
 #define HAVE_STRING_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_SYSLOG_H 1
+#define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_LINUX_AUTO_FS_H 1
+#define HAVE_LINUX_AUTO_FS4_H 1
+#define HAVE_LINUX_LOOP_H 1
+#define HAVE_LINUX_NFS_MOUNT_H 1
+#define NEW_DBM_H "gdbm/ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_linux.h"
 #define HAVE_STRUCT_MNTENT 1
+#define HAVE_BAD_HASMNTOPT 1
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD root
 #define am_nfs_fh nfs_fh
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
 #define MTYPE_TYPE char *
 #define MTYPE_PRINTF_TYPE "%s"
-#define YP_ORDER_OUTORDER_TYPE int
-#define RECVFROM_FROMLEN_TYPE int
+#define YP_ORDER_OUTORDER_TYPE unsigned int
+#define RECVFROM_FROMLEN_TYPE unsigned int
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -244,6 +268,7 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
@@ -251,20 +276,23 @@
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
+#define HAVE_EXTERN_XDR_CALLMSG 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
-#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_BSIZE 1
-#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
-#define HAVE_FIELD_NFS_ARGS_T_NAMLEN 1
-#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
-#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
-#define HAVE_FIELD_UMNTREQUEST_RDEVID 1
+#define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
+#define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
+#define HAVE_NFS_ARGS_T_BSIZE 1
+#define HAVE_NFS_ARGS_T_FHSIZE 1
+#define HAVE_NFS_ARGS_T_NAMLEN 1
+#define HAVE_NFS_ARGS_T_VERSION 1
+#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_MAP_FILE 1
-#define HAVE_MAP_LDAP 1
+#define HAVE_MAP_SUN 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_NISPLUS 1
@@ -274,7 +302,6 @@
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_LOFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_TMPFS 1
 #define HAVE_FS_UFS 1
@@ -282,7 +309,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -313,6 +339,8 @@
 #define MNTTAB_OPT_RW "rw"
 #define MNTTAB_OPT_SUID "suid"
 #define MNT2_GEN_OPT_BIND 0x1000
+#define MNT2_GEN_OPT_DETACH 0x2
+#define MNT2_GEN_OPT_FORCE 0x1
 #define MNT2_GEN_OPT_NODEV 0x4
 #define MNT2_GEN_OPT_NOEXEC 0x8
 #define MNT2_GEN_OPT_NOSUID 0x2
